@@ -5,6 +5,6 @@ class Command(BaseCommand):
     help = 'Loads data for pluggable maps of U.S. counties'
 
     def handle(self, *args, **options):
-        self.stdout.write('Loading data for U.S. counties\n')
+        print 'Loading data for U.S. counties'
         load.all()
-        self.stdout.write('Successfully loaded data for U.S. counties\n')
+        print 'Successfully loaded data for U.S. counties'
